Enum codeforces_api::requests::CFUserCommand [−][src]
Wrapper enum for all API methods of form user.<method>.
More details for the user command can be found here.
Variants
Struct for sending user.blogEntries requests to the Codeforces
API.
Returns a list with all of a specified user’s blog entries.
If correctly parsed, the response object will be of type
responses::CFResult::CFBlogEntryVec.
More details for the user.blogEntries command can be found
here.
Examples
let x = CFUserCommand::BlogEntries { handle: "thud".to_string(), }; match x.get(api_key, api_secret) { Ok(CFResult::CFBlogEntryVec(v)) => { // your code here }, _ => { panic!("API request failed"); } }
Fields of BlogEntries
handle: StringCodeforces handle of the user for which to fetch blog entries.
Struct for sending user.friends requests to the Codeforces API.
Returns authorized user’s friends (ie. the friends of the user who owns the API keys in use).
If correctly parsed, the response object will be of type
responses::CFResult::CFFriends.
More details for the user.friends command can be found
here.
Examples
let x = CFUserCommand::Friends { only_online: None, }; match x.get(api_key, api_secret) { Ok(CFResult::CFFriends(v)) => { // your code here }, _ => { panic!("API request failed"); } }
Fields of Friends
Struct for sending user.info requests to the Codeforces API.
Returns information about one or several users.
If correctly parsed, the response object will be of type
responses::CFResult::CFUserVec.
More details for the user.info command can be found
here.
Examples
let x = CFUserCommand::Info { handles: vec!["thud".to_string()], }; match x.get(api_key, api_secret) { Ok(CFResult::CFUserVec(v)) => { // your code here }, _ => { panic!("API request failed"); } }
Fields of Info
Struct for sending user.ratedList requests to the Codeforces API.
Returns the list of users who have participated in at least one rated contest.
If correctly parsed, the response object will be of type
responses::CFResult::CFUserVec.
More details for the user.ratedList command can be found
here.
Examples
let x = CFUserCommand::RatedList { active_only: Some(true), }; match x.get(api_key, api_secret) { Ok(CFResult::CFUserVec(v)) => { // your code here }, _ => { panic!("API request failed"); } }
Fields of RatedList
Struct for sending user.rating requests to the Codeforces API.
Returns the rating history of a specified user.
If correctly parsed, the response object will be of type
responses::CFResult::CFRatingChangeVec.
More details for the user.rating command can be found
here.
Examples
let x = CFUserCommand::Rating { handle: "thud".to_string(), }; match x.get(api_key, api_secret) { Ok(CFResult::CFRatingChangeVec(v)) => { // your code here }, _ => { panic!("API request failed"); } }
Fields of Rating
handle: StringCodeforces handle of user for which to fetch rating changes for.
Struct for sending user.status requests to the Codeforces API.
Returns the submissions of a specified user.
If correctly parsed, the response object will be of type
responses::CFResult::CFSubmissionVec.
More details for the user.status command can be found
here.
Examples
let x = CFUserCommand::Status { handle: "thud".to_string(), from: Some(1), count: Some(3), }; match x.get(api_key, api_secret) { Ok(CFResult::CFSubmissionVec(v)) => { // your code here }, _ => { panic!("API request failed"); } }
Fields of Status