Module codeforces_api::responses [−][src]
Contains the structs etc. which are returned by the Codeforces API following a request.
Structs
| CFBlogEntry | Struct representing a Codeforces blog entry. |
| CFComment | Struct representing a Codeforces blog entry comment. |
| CFContest | Struct representing a Codeforces contest. |
| CFContestStandings | Struct representing the object returned by a
|
| CFHack | Struct representing a Codeforces hack. |
| CFJudgeProtocol | Struct representing a Codeforces judge protocol for hacks. |
| CFMember | Struct representing a Codeforces member. |
| CFParty | Struct representing a Codeforces party. |
| CFProblem | Struct representing a Codeforces problem. |
| CFProblemResult | Struct representing a Codeforces problem result. |
| CFProblemStatistics | Struct representing a Codeforces problem statistics. |
| CFProblemset | Struct representing the object returned by a
|
| CFRanklistRow | Struct representing a Codeforces ranklist row. |
| CFRatingChange | Struct representing a Codeforces rating change. |
| CFRecentAction | Struct representing a Codeforces recent action. |
| CFResponse | Response type used internally which directly represents network responses sent back from the Codeforces API. |
| CFSubmission | Struct representing a Codeforces submission. |
| CFUser | Struct representing a Codeforces user. |
Enums
| CFContestPhase | Contest phase returned by Codeforces API (eg. PendingSystemTest). |
| CFContestType | Contest type returned by Codeforces API (eg. IOI, ICPC). |
| CFHackVerdict | Hack verdict returned by Codeforces API (eg. HackSuccessful, Testing). |
| CFParticipantType | Participant type returned by Codeforces API (eg. Contestant, Virtual). |
| CFProblemResultType | Problem result type returned by Codeforces API (Preliminary, Final). |
| CFProblemType | Problem type returned by Codeforces API (Programming, Question). |
| CFResponseStatus | Response code returned by Codeforces API (Ok, Failed). |
| CFResult | Wrapper for all forms of result returned by the Codeforces API. |
| CFSubmissionVerdict | Submission verdict returned by Codeforces API (eg. Ok, CompilationError). |
| CFTestset | Testset returned by Codeforces API (eg. Pretests, TestSet1). |