Struct codeforces_api::responses::CFProblem [−][src]
Struct representing a Codeforces problem.
Fields
contest_id: Option<i64>problemset_name: Option<String>index: Option<String>name: Stringproblem_type: CFProblemTypepoints: Option<f64>rating: Option<i64>input_testcases: Option<Vec<String>>Implementations
impl CFProblem[src]
pub fn fetch_testcases(&mut self) -> Result<Vec<String>, Error>[src]
Extra method which allows a user to fetch testcases directly from a
CFProblem.
Returns Vec of Strings where each String is a separate input testcase for the problem. Currently, the 'expected output' provided by Codeforces is not returned. However, in future this could be implemented relatively easily.
Uses fetch_testcases_for_problem under the hood.