Enum codeforces_api::requests::CFBlogEntryCommand [−][src]
Wrapper enum for all API methods of form blogEntry.<method>.
More details for the blogEntry command can be found here.
Variants
Struct for sending blogEntry.comments requests to the Codeforces API.
Returns a list of comments on a specified blog entry.
If correctly parsed, the response object will be of type
responses::CFResult::CFCommentVec.
More details for the blogEntry.comments command can be found
here.
Examples
let x = CFBlogEntryCommand::Comments { blog_entry_id: 82347, }; match x.get(api_key, api_secret) { Ok(CFResult::CFCommentVec(v)) => { // your code here }, _ => { panic!("API request failed"); } }
Fields of Comments
blog_entry_id: i64blogEntryId of a blog (can be seen in the url of a blog, eg.
/blog/entry/82347).
Struct for sending blogEntry.view requests to the Codeforces API.
Returns a specified blog entry.
If correctly parsed, the response object will be of type
responses::CFResult::CFBlogEntry.
More details for the blogEntry.view command can be found
here.
Examples
let x = CFBlogEntryCommand::View { blog_entry_id: 82347, }; match x.get(api_key, api_secret) { Ok(CFResult::CFBlogEntry(e)) => { // your code here }, _ => { panic!("API request failed"); } }
Fields of View
blog_entry_id: i64blogEntryId of a blog (can be seen in the url of a blog, eg.
/blog/entry/82347).